Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/zabbix/zabbix.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/zabbix_server/escalator/escalator.c')
-rw-r--r--src/zabbix_server/escalator/escalator.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/zabbix_server/escalator/escalator.c b/src/zabbix_server/escalator/escalator.c
index 96ad3046ac7..18f3b69e7aa 100644
--- a/src/zabbix_server/escalator/escalator.c
+++ b/src/zabbix_server/escalator/escalator.c
@@ -1799,7 +1799,7 @@ static int check_operation_conditions(const ZBX_DB_EVENT *event, zbx_uint64_t op
DB_ROW row;
zbx_condition_t condition;
- int ret = SUCCEED; /* SUCCEED required for ZBX_ACTION_CONDITION_EVAL_TYPE_AND_OR */
+ int ret = SUCCEED; /* SUCCEED required for ZBX_CONDITION_EVAL_TYPE_AND_OR */
int cond, exit = 0;
unsigned char old_type = 0xff;
@@ -1825,7 +1825,7 @@ static int check_operation_conditions(const ZBX_DB_EVENT *event, zbx_uint64_t op
switch (evaltype)
{
- case ZBX_ACTION_CONDITION_EVAL_TYPE_AND_OR:
+ case ZBX_CONDITION_EVAL_TYPE_AND_OR:
if (old_type == condition.conditiontype) /* OR conditions */
{
if (SUCCEED == check_action_condition(event, &condition))
@@ -1841,7 +1841,7 @@ static int check_operation_conditions(const ZBX_DB_EVENT *event, zbx_uint64_t op
}
old_type = condition.conditiontype;
break;
- case ZBX_ACTION_CONDITION_EVAL_TYPE_AND:
+ case ZBX_CONDITION_EVAL_TYPE_AND:
cond = check_action_condition(event, &condition);
/* Break if any of AND conditions is FALSE */
if (cond == FAIL)
@@ -1852,7 +1852,7 @@ static int check_operation_conditions(const ZBX_DB_EVENT *event, zbx_uint64_t op
else
ret = SUCCEED;
break;
- case ZBX_ACTION_CONDITION_EVAL_TYPE_OR:
+ case ZBX_CONDITION_EVAL_TYPE_OR:
cond = check_action_condition(event, &condition);
/* Break if any of OR conditions is TRUE */
if (cond == SUCCEED)